#!/usr/bin/perl -w

use strict;
use LJ::Simple;
use Mail::Mailer;
use Text::Iconv;
use MIME::Base64;

#
# Configuration
#

# LiveJournal credentials
my $lj_username = 'someuser';
my $lj_password = 'somepass';

# Encoding for email
my $from_enc = 'utf-8';
my $to_enc   = 'koi8-r';

# Where to store the timestamp of last sync
my $file_stamp  = '/tmp/lj.timestamp';

# Recepients of the email
my @recepients = (
					'John Doe <jonh@here.com>',
					'Foo Bar <foo@bar.com>',
				);

# From field value for outgoing emails
my $from = 'Blah Blogger <blah@blogger.biz>';

#######################################################################

# Initialize the timestamp of the last sync
my $timestamp = 0;
if (-e $file_stamp) {
	open(TIME,"<$file_stamp") or die "Couldn't read timestamp file $file_stamp : $!\n";
	$timestamp = <TIME>;
	close(TIME);
	chomp($timestamp);
}

# Connect to LiveJournal
my $lj = LJ::Simple->new({user=>$lj_username,pass=>$lj_password});
die "$0: Failed to access LiveJournal - $LJ::Simple::error\n" unless (defined $lj);

# Get entries from the last sync
my %items = ();
my $result = $lj->GetEntries(\%items,undef,'sync',$timestamp);
die "Failed to get entries : $LJ::Simple::error\n" unless (defined $result);

# Process new entries
my $maxdate = 0;
my $converter = Text::Iconv->new($from_enc, $to_enc);
foreach my $item (sort {$lj->GetDate($a) <=> $lj->GetDate($b)} values %items) {
	# Get all sorts of entry properties
	my $url = $lj->GetURL($item);
	my $text = $lj->GetEntry($item);
	$text = $converter->convert($text);
	my $subject = $lj->GetSubject($item);
	chomp($subject);
	$subject = $converter->convert($subject);
	$subject = '=?' . $to_enc . '?B?' . encode_base64($subject,'') . '?=';
	my $date = $lj->GetDate($item);
	chomp($date);

	# Bump up the time of the last sync to maximum
	$maxdate = $date if ($date > $maxdate);

	# Send an email with the entry
	my $mailer = Mail::Mailer->new();
	my %headers = (
					'Content-Type' => 'text/plain; charset=' . $to_enc,
					'To' => join(', ', @recepients),
					'From' => $from,
					'Subject' => $subject,
				);
	$mailer->open(\%headers);
	print $mailer "$text\n\nURL: $url\n";
	$mailer->close();
}

# Update time of the last sync in the file
open(TIME,">$file_stamp") or die "Couldn't write timestamp file $file_stamp : $!\n";
print TIME $maxdate;
close(TIME);

